import java.awt.*;
import java.util.Comparator;

public class PlaneCompareByColor implements Comparator<IDrawningObject>
{
    @Override
    public int compare(IDrawningObject x, IDrawningObject y)
    {
        if (x == null && y == null)
        {
            return 0;
        }

        if (x == null && y != null)
        {
            return 1;
        }

        if (x != null && y == null)
        {
            return -1;
        }

        DrawningObjectPlane xPlane = (DrawningObjectPlane)x;
        DrawningObjectPlane yPlane = (DrawningObjectPlane)y;

        if (xPlane == null && yPlane == null)
        {
            return 0;
        }

        if (xPlane == null && yPlane != null)
        {
            return 1;
        }

        if (xPlane != null && yPlane == null)
        {
            return -1;
        }

        var xEntityPlane = xPlane.GetPlane().Plane;
        var yEntityPlane = yPlane.GetPlane().Plane;

        Integer colorCompare1 = xEntityPlane.GetColor().getRGB();
        Integer colorCompare2 = yEntityPlane.GetColor().getRGB();
        var colorCompare = colorCompare1.compareTo(colorCompare2);

        if (colorCompare != 0)
        {
            return colorCompare;
        }

        if (xEntityPlane instanceof EntityAirbus xAirbus && yEntityPlane instanceof EntityAirbus yAirbus)
        {
            Integer dopColorCompare1 = xAirbus.AddColor().getRGB();
            Integer dopColorCompare2 = yAirbus.AddColor().getRGB();
            var addColorCompare = dopColorCompare1.compareTo(dopColorCompare2);

            if(addColorCompare != 0)
            {
                return addColorCompare;
            }
        }

        Integer speedCompare1 = xPlane.GetPlane().Plane.GetSpeed();
        Integer speedCompare2 = yPlane.GetPlane().Plane.GetSpeed();
        var speedCompare = speedCompare1.compareTo(speedCompare2);
        
        if(speedCompare != 0)
        {
            return speedCompare;
        }

        Float weightCompare1 = xPlane.GetPlane().Plane.GetWeight();
        Float weightCompare2 = yPlane.GetPlane().Plane.GetWeight();

        return weightCompare1.compareTo(weightCompare2);
    }
}
